# PolymorphicPiEventRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**created_dt** | **datetime** |  | [optional] 
**subject_pattern** | [**PiBootCommandSubjectPatternEnum**](PiBootCommandSubjectPatternEnum.md) |  | 
**payload** | **dict(str, object)** |  | 
**event_type** | [**PiBootCommandType**](PiBootCommandType.md) |  | 
**pi** | **int** |  | 
**version** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


